@@ -33,7 +33,7 @@
 #include <config-konqueror.h>
 #include <konqueror-version.h>
 
-#include <QDebug>
+#include "konqdebug.h"
 #include <QFile>
 #include <QDir>
 #include <QDirIterator>
@@ -59,7 +59,7 @@ static KonqMainWindow* handleCommandLine(QCommandLineParser &parser, const QStri
 {
     *ret = 0;
     const QStringList args = parser.positionalArguments();
-    qDebug() << "args=" << args;
+    qCDebug(KONQUEROR_LOG) << "args=" << args;
     // First the invocations that do not take urls.
     if (parser.isSet("sessions")) {
         listSessions();
@@ -73,16 +73,27 @@ static KonqMainWindow* handleCommandLine(QCommandLineParser &parser, const QStri
 
         QDirIterator it(sessionPath, QDir::Readable | QDir::Files);
         if (!it.hasNext()) {
-            qWarning() << "session" << session << "not found or empty";
+            qCWarning(KONQUEROR_LOG) << "session" << session << "not found or empty";
             *ret = 1;
             return nullptr;
         }
 
         KonqSessionManager::self()->restoreSessions(sessionPath);
-            return nullptr;
-    } else if (args.isEmpty()) {
+        return nullptr;
+    }
+
+    // Ask the user to recover session if applicable
+    KonqSessionManager::self()->askUserToRestoreAutosavedAbandonedSessions();
+
+    if (args.isEmpty()) {
         // No args. If --silent, do nothing, otherwise create a default window.
         if (!parser.isSet("silent")) {
+            // If session recovery created some windows, no need for an empty window here.
+            QList<KonqMainWindow *> *mainWindowList = KonqMainWindow::mainWindowList();
+            if (mainWindowList && !mainWindowList->isEmpty()) {
+                return mainWindowList->at(0);
+            }
+
             KonqMainWindow *mainWin = KonqMainWindowFactory::createNewWindow();
             mainWin->show();
             return mainWin;
@@ -152,7 +163,8 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     aboutData.setCopyrightStatement(i18n("(C) 1999-2016, The Konqueror developers"));
     aboutData.setHomepage("http://konqueror.kde.org");
 
-    aboutData.addAuthor(i18n("David Faure"), i18n("Developer (framework, parts, JavaScript, I/O library) and maintainer"), "faure@kde.org");
+    aboutData.addAuthor(i18n("Stefano Crocco"), i18n("Current maintainer"), "stefano.crocco@alice.it");
+    aboutData.addAuthor(i18n("David Faure"), i18n("Developer (framework, parts, JavaScript, I/O library) and former maintainer"), "faure@kde.org");
     aboutData.addAuthor(i18n("Simon Hausmann"), i18n("Developer (framework, parts)"), "hausmann@kde.org");
     aboutData.addAuthor(i18n("Michael Reiher"), i18n("Developer (framework)"), "michael.reiher@gmx.de");
     aboutData.addAuthor(i18n("Matthias Welk"), i18n("Developer"), "welk@fokus.gmd.de");
@@ -234,7 +246,7 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
             if (className == QLatin1String("KonqMainWindow")) {
                 (new KonqMainWindow())->restore(n);
             } else {
-                qWarning() << "Unknown class" << className << "in session saved data!";
+                qCWarning(KONQUEROR_LOG) << "Unknown class" << className << "in session saved data!";
             }
             ++n;
         }
